0.7.1 - Minor bugfixes
----------------------

Fixes:
    - Fix issue when Cohen fails to be discovered by xbox 360 dlna client
    - Fix issue when using Lazy Container on Samsung AllShare on 2012 Samsung TV fails

0.7.0 - Cohen project started
-----------------------------

General:
    - lots of refactoring
    - removed lots of Coherence stuff
    - moved to lxml instead of (c)ElementTree
    - Twisted >= 14.0 is now required
    - livestreamer is now required
    - cleanups and fixes

Backends:
    - twitch.tv backend added


0.0.1 - 0.7.0 - Coherence project
---------------------------------

Changelog skipped